// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
#define THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_

#include <stddef.h>

#include "base/check_op.h"
#include "third_party/blink/public/mojom/use_counter/metrics/css_property_id.mojom-blink-forward.h"
#include "third_party/blink/renderer/core/core_export.h"
#include "third_party/blink/renderer/platform/wtf/allocator/allocator.h"
#include "third_party/blink/renderer/platform/wtf/hash_functions.h"
#include "third_party/blink/renderer/platform/wtf/hash_traits.h"

namespace WTF {
class AtomicString;
class String;
}  // namespace WTF

namespace blink {

class ExecutionContext;

enum class CSSPropertyID {
    kInvalid = 0,
    kVariable = 1,
    kColorScheme = 2,
    kForcedColorAdjust = 3,
    kMaskImage = 4,
    kMathDepth = 5,
    kWebkitMaskImage = 6,
    kColor = 7,
    kDirection = 8,
    kFontFamily = 9,
    kFontFeatureSettings = 10,
    kFontKerning = 11,
    kFontOpticalSizing = 12,
    kFontPalette = 13,
    kFontSize = 14,
    kFontSizeAdjust = 15,
    kFontStretch = 16,
    kFontStyle = 17,
    kFontSynthesisSmallCaps = 18,
    kFontSynthesisStyle = 19,
    kFontSynthesisWeight = 20,
    kFontVariantAlternates = 21,
    kFontVariantCaps = 22,
    kFontVariantEastAsian = 23,
    kFontVariantLigatures = 24,
    kFontVariantNumeric = 25,
    kFontVariantPosition = 26,
    kFontVariationSettings = 27,
    kFontWeight = 28,
    kInternalVisitedColor = 29,
    kPosition = 30,
    kTextOrientation = 31,
    kTextRendering = 32,
    kTextSpacingTrim = 33,
    kWebkitFontSmoothing = 34,
    kWebkitLocale = 35,
    kWebkitTextOrientation = 36,
    kWebkitWritingMode = 37,
    kWritingMode = 38,
    kZoom = 39,
    kAccentColor = 40,
    kAdditiveSymbols = 41,
    kAlignContent = 42,
    kAlignItems = 43,
    kAlignSelf = 44,
    kAlignmentBaseline = 45,
    kAll = 46,
    kAnchorName = 47,
    kAnimationComposition = 48,
    kAnimationDelay = 49,
    kAnimationDelayEnd = 50,
    kAnimationDelayStart = 51,
    kAnimationDirection = 52,
    kAnimationDuration = 53,
    kAnimationFillMode = 54,
    kAnimationIterationCount = 55,
    kAnimationName = 56,
    kAnimationPlayState = 57,
    kAnimationRangeEnd = 58,
    kAnimationRangeStart = 59,
    kAnimationTimeline = 60,
    kAnimationTimingFunction = 61,
    kAppRegion = 62,
    kAppearance = 63,
    kAscentOverride = 64,
    kAspectRatio = 65,
    kBackdropFilter = 66,
    kBackfaceVisibility = 67,
    kBackgroundAttachment = 68,
    kBackgroundBlendMode = 69,
    kBackgroundClip = 70,
    kBackgroundColor = 71,
    kBackgroundImage = 72,
    kBackgroundOrigin = 73,
    kBackgroundPositionX = 74,
    kBackgroundPositionY = 75,
    kBackgroundRepeat = 76,
    kBackgroundSize = 77,
    kBasePalette = 78,
    kBaselineShift = 79,
    kBaselineSource = 80,
    kBlockSize = 81,
    kBorderBlockEndColor = 82,
    kBorderBlockEndStyle = 83,
    kBorderBlockEndWidth = 84,
    kBorderBlockStartColor = 85,
    kBorderBlockStartStyle = 86,
    kBorderBlockStartWidth = 87,
    kBorderBottomColor = 88,
    kBorderBottomLeftRadius = 89,
    kBorderBottomRightRadius = 90,
    kBorderBottomStyle = 91,
    kBorderBottomWidth = 92,
    kBorderCollapse = 93,
    kBorderEndEndRadius = 94,
    kBorderEndStartRadius = 95,
    kBorderImageOutset = 96,
    kBorderImageRepeat = 97,
    kBorderImageSlice = 98,
    kBorderImageSource = 99,
    kBorderImageWidth = 100,
    kBorderInlineEndColor = 101,
    kBorderInlineEndStyle = 102,
    kBorderInlineEndWidth = 103,
    kBorderInlineStartColor = 104,
    kBorderInlineStartStyle = 105,
    kBorderInlineStartWidth = 106,
    kBorderLeftColor = 107,
    kBorderLeftStyle = 108,
    kBorderLeftWidth = 109,
    kBorderRightColor = 110,
    kBorderRightStyle = 111,
    kBorderRightWidth = 112,
    kBorderStartEndRadius = 113,
    kBorderStartStartRadius = 114,
    kBorderTopColor = 115,
    kBorderTopLeftRadius = 116,
    kBorderTopRightRadius = 117,
    kBorderTopStyle = 118,
    kBorderTopWidth = 119,
    kBottom = 120,
    kBoxShadow = 121,
    kBoxSizing = 122,
    kBreakAfter = 123,
    kBreakBefore = 124,
    kBreakInside = 125,
    kBufferedRendering = 126,
    kCaptionSide = 127,
    kCaretColor = 128,
    kClear = 129,
    kClip = 130,
    kClipPath = 131,
    kClipRule = 132,
    kColorInterpolation = 133,
    kColorInterpolationFilters = 134,
    kColorRendering = 135,
    kColumnCount = 136,
    kColumnFill = 137,
    kColumnGap = 138,
    kColumnRuleColor = 139,
    kColumnRuleStyle = 140,
    kColumnRuleWidth = 141,
    kColumnSpan = 142,
    kColumnWidth = 143,
    kContain = 144,
    kContainIntrinsicBlockSize = 145,
    kContainIntrinsicHeight = 146,
    kContainIntrinsicInlineSize = 147,
    kContainIntrinsicWidth = 148,
    kContainerName = 149,
    kContainerType = 150,
    kContent = 151,
    kContentVisibility = 152,
    kCounterIncrement = 153,
    kCounterReset = 154,
    kCounterSet = 155,
    kCursor = 156,
    kCx = 157,
    kCy = 158,
    kD = 159,
    kDescentOverride = 160,
    kDisplay = 161,
    kDominantBaseline = 162,
    kDynamicRangeLimit = 163,
    kEmptyCells = 164,
    kFallback = 165,
    kFieldSizing = 166,
    kFill = 167,
    kFillOpacity = 168,
    kFillRule = 169,
    kFilter = 170,
    kFlexBasis = 171,
    kFlexDirection = 172,
    kFlexGrow = 173,
    kFlexShrink = 174,
    kFlexWrap = 175,
    kFloat = 176,
    kFloodColor = 177,
    kFloodOpacity = 178,
    kFontDisplay = 179,
    kGridAutoColumns = 180,
    kGridAutoFlow = 181,
    kGridAutoRows = 182,
    kGridColumnEnd = 183,
    kGridColumnStart = 184,
    kGridRowEnd = 185,
    kGridRowStart = 186,
    kGridTemplateAreas = 187,
    kGridTemplateColumns = 188,
    kGridTemplateRows = 189,
    kHeight = 190,
    kHyphenateCharacter = 191,
    kHyphenateLimitChars = 192,
    kHyphens = 193,
    kImageOrientation = 194,
    kImageRendering = 195,
    kInherits = 196,
    kInitialLetter = 197,
    kInitialValue = 198,
    kInlineSize = 199,
    kInsetArea = 200,
    kInsetBlockEnd = 201,
    kInsetBlockStart = 202,
    kInsetInlineEnd = 203,
    kInsetInlineStart = 204,
    kInternalAlignContentBlock = 205,
    kInternalEmptyLineHeight = 206,
    kInternalFontSizeDelta = 207,
    kInternalForcedBackgroundColor = 208,
    kInternalForcedBorderColor = 209,
    kInternalForcedColor = 210,
    kInternalForcedOutlineColor = 211,
    kInternalForcedVisitedColor = 212,
    kInternalOverflowBlock = 213,
    kInternalOverflowInline = 214,
    kInternalVisitedBackgroundColor = 215,
    kInternalVisitedBorderBlockEndColor = 216,
    kInternalVisitedBorderBlockStartColor = 217,
    kInternalVisitedBorderBottomColor = 218,
    kInternalVisitedBorderInlineEndColor = 219,
    kInternalVisitedBorderInlineStartColor = 220,
    kInternalVisitedBorderLeftColor = 221,
    kInternalVisitedBorderRightColor = 222,
    kInternalVisitedBorderTopColor = 223,
    kInternalVisitedCaretColor = 224,
    kInternalVisitedColumnRuleColor = 225,
    kInternalVisitedFill = 226,
    kInternalVisitedOutlineColor = 227,
    kInternalVisitedStroke = 228,
    kInternalVisitedTextDecorationColor = 229,
    kInternalVisitedTextEmphasisColor = 230,
    kInternalVisitedTextFillColor = 231,
    kInternalVisitedTextStrokeColor = 232,
    kIsolation = 233,
    kJustifyContent = 234,
    kJustifyItems = 235,
    kJustifySelf = 236,
    kLeft = 237,
    kLetterSpacing = 238,
    kLightingColor = 239,
    kLineBreak = 240,
    kLineGapOverride = 241,
    kLineHeight = 242,
    kListStyleImage = 243,
    kListStylePosition = 244,
    kListStyleType = 245,
    kMarginBlockEnd = 246,
    kMarginBlockStart = 247,
    kMarginBottom = 248,
    kMarginInlineEnd = 249,
    kMarginInlineStart = 250,
    kMarginLeft = 251,
    kMarginRight = 252,
    kMarginTop = 253,
    kMarkerEnd = 254,
    kMarkerMid = 255,
    kMarkerStart = 256,
    kMask = 257,
    kMaskClip = 258,
    kMaskComposite = 259,
    kMaskMode = 260,
    kMaskOrigin = 261,
    kMaskRepeat = 262,
    kMaskSize = 263,
    kMaskType = 264,
    kMathShift = 265,
    kMathStyle = 266,
    kMaxBlockSize = 267,
    kMaxHeight = 268,
    kMaxInlineSize = 269,
    kMaxWidth = 270,
    kMinBlockSize = 271,
    kMinHeight = 272,
    kMinInlineSize = 273,
    kMinWidth = 274,
    kMixBlendMode = 275,
    kNavigation = 276,
    kNegative = 277,
    kObjectFit = 278,
    kObjectPosition = 279,
    kObjectViewBox = 280,
    kOffsetAnchor = 281,
    kOffsetDistance = 282,
    kOffsetPath = 283,
    kOffsetPosition = 284,
    kOffsetRotate = 285,
    kOpacity = 286,
    kOrder = 287,
    kOriginTrialTestProperty = 288,
    kOrphans = 289,
    kOutlineColor = 290,
    kOutlineOffset = 291,
    kOutlineStyle = 292,
    kOutlineWidth = 293,
    kOverflowAnchor = 294,
    kOverflowBlock = 295,
    kOverflowClipMargin = 296,
    kOverflowInline = 297,
    kOverflowWrap = 298,
    kOverflowX = 299,
    kOverflowY = 300,
    kOverlay = 301,
    kOverrideColors = 302,
    kOverscrollBehaviorBlock = 303,
    kOverscrollBehaviorInline = 304,
    kOverscrollBehaviorX = 305,
    kOverscrollBehaviorY = 306,
    kPad = 307,
    kPaddingBlockEnd = 308,
    kPaddingBlockStart = 309,
    kPaddingBottom = 310,
    kPaddingInlineEnd = 311,
    kPaddingInlineStart = 312,
    kPaddingLeft = 313,
    kPaddingRight = 314,
    kPaddingTop = 315,
    kPage = 316,
    kPageOrientation = 317,
    kPaintOrder = 318,
    kPerspective = 319,
    kPerspectiveOrigin = 320,
    kPointerEvents = 321,
    kPopoverHideDelay = 322,
    kPopoverShowDelay = 323,
    kPositionAnchor = 324,
    kPositionFallbackBounds = 325,
    kPositionTryOptions = 326,
    kPositionTryOrder = 327,
    kPrefix = 328,
    kQuotes = 329,
    kR = 330,
    kRange = 331,
    kReadingOrderItems = 332,
    kResize = 333,
    kRight = 334,
    kRotate = 335,
    kRowGap = 336,
    kRubyPosition = 337,
    kRx = 338,
    kRy = 339,
    kScale = 340,
    kScrollBehavior = 341,
    kScrollMarginBlockEnd = 342,
    kScrollMarginBlockStart = 343,
    kScrollMarginBottom = 344,
    kScrollMarginInlineEnd = 345,
    kScrollMarginInlineStart = 346,
    kScrollMarginLeft = 347,
    kScrollMarginRight = 348,
    kScrollMarginTop = 349,
    kScrollPaddingBlockEnd = 350,
    kScrollPaddingBlockStart = 351,
    kScrollPaddingBottom = 352,
    kScrollPaddingInlineEnd = 353,
    kScrollPaddingInlineStart = 354,
    kScrollPaddingLeft = 355,
    kScrollPaddingRight = 356,
    kScrollPaddingTop = 357,
    kScrollSnapAlign = 358,
    kScrollSnapStop = 359,
    kScrollSnapType = 360,
    kScrollStartBlock = 361,
    kScrollStartInline = 362,
    kScrollStartTargetBlock = 363,
    kScrollStartTargetInline = 364,
    kScrollStartTargetX = 365,
    kScrollStartTargetY = 366,
    kScrollStartX = 367,
    kScrollStartY = 368,
    kScrollTimelineAxis = 369,
    kScrollTimelineName = 370,
    kScrollbarColor = 371,
    kScrollbarGutter = 372,
    kScrollbarWidth = 373,
    kShapeImageThreshold = 374,
    kShapeMargin = 375,
    kShapeOutside = 376,
    kShapeRendering = 377,
    kSize = 378,
    kSizeAdjust = 379,
    kSpeak = 380,
    kSpeakAs = 381,
    kSrc = 382,
    kStopColor = 383,
    kStopOpacity = 384,
    kStroke = 385,
    kStrokeDasharray = 386,
    kStrokeDashoffset = 387,
    kStrokeLinecap = 388,
    kStrokeLinejoin = 389,
    kStrokeMiterlimit = 390,
    kStrokeOpacity = 391,
    kStrokeWidth = 392,
    kSuffix = 393,
    kSymbols = 394,
    kSyntax = 395,
    kSystem = 396,
    kTabSize = 397,
    kTableLayout = 398,
    kTextAlign = 399,
    kTextAlignLast = 400,
    kTextAnchor = 401,
    kTextAutospace = 402,
    kTextBoxEdge = 403,
    kTextBoxTrim = 404,
    kTextCombineUpright = 405,
    kTextDecorationColor = 406,
    kTextDecorationLine = 407,
    kTextDecorationSkipInk = 408,
    kTextDecorationStyle = 409,
    kTextDecorationThickness = 410,
    kTextEmphasisColor = 411,
    kTextEmphasisPosition = 412,
    kTextEmphasisStyle = 413,
    kTextIndent = 414,
    kTextOverflow = 415,
    kTextShadow = 416,
    kTextSizeAdjust = 417,
    kTextTransform = 418,
    kTextUnderlineOffset = 419,
    kTextUnderlinePosition = 420,
    kTextWrap = 421,
    kTimelineScope = 422,
    kTop = 423,
    kTouchAction = 424,
    kTransform = 425,
    kTransformBox = 426,
    kTransformOrigin = 427,
    kTransformStyle = 428,
    kTransitionBehavior = 429,
    kTransitionDelay = 430,
    kTransitionDuration = 431,
    kTransitionProperty = 432,
    kTransitionTimingFunction = 433,
    kTranslate = 434,
    kUnicodeBidi = 435,
    kUnicodeRange = 436,
    kUserSelect = 437,
    kVectorEffect = 438,
    kVerticalAlign = 439,
    kViewTimelineAxis = 440,
    kViewTimelineInset = 441,
    kViewTimelineName = 442,
    kViewTransitionClass = 443,
    kViewTransitionName = 444,
    kVisibility = 445,
    kWebkitBorderHorizontalSpacing = 446,
    kWebkitBorderImage = 447,
    kWebkitBorderVerticalSpacing = 448,
    kWebkitBoxAlign = 449,
    kWebkitBoxDecorationBreak = 450,
    kWebkitBoxDirection = 451,
    kWebkitBoxFlex = 452,
    kWebkitBoxOrdinalGroup = 453,
    kWebkitBoxOrient = 454,
    kWebkitBoxPack = 455,
    kWebkitBoxReflect = 456,
    kWebkitLineBreak = 457,
    kWebkitLineClamp = 458,
    kWebkitMaskBoxImageOutset = 459,
    kWebkitMaskBoxImageRepeat = 460,
    kWebkitMaskBoxImageSlice = 461,
    kWebkitMaskBoxImageSource = 462,
    kWebkitMaskBoxImageWidth = 463,
    kWebkitMaskClip = 464,
    kWebkitMaskComposite = 465,
    kWebkitMaskOrigin = 466,
    kWebkitMaskPositionX = 467,
    kWebkitMaskPositionY = 468,
    kWebkitMaskRepeat = 469,
    kWebkitMaskSize = 470,
    kWebkitPerspectiveOriginX = 471,
    kWebkitPerspectiveOriginY = 472,
    kWebkitPrintColorAdjust = 473,
    kWebkitRtlOrdering = 474,
    kWebkitRubyPosition = 475,
    kWebkitTapHighlightColor = 476,
    kWebkitTextCombine = 477,
    kWebkitTextDecorationsInEffect = 478,
    kWebkitTextFillColor = 479,
    kWebkitTextSecurity = 480,
    kWebkitTextStrokeColor = 481,
    kWebkitTextStrokeWidth = 482,
    kWebkitTransformOriginX = 483,
    kWebkitTransformOriginY = 484,
    kWebkitTransformOriginZ = 485,
    kWebkitUserDrag = 486,
    kWebkitUserModify = 487,
    kWhiteSpaceCollapse = 488,
    kWidows = 489,
    kWidth = 490,
    kWillChange = 491,
    kWordBreak = 492,
    kWordSpacing = 493,
    kX = 494,
    kY = 495,
    kZIndex = 496,
    kAlternativeAnimationDelay = 497,
    kAlternativeAnimationWithDelayStartEnd = 498,
    kAlternativeAnimationWithTimeline = 499,
    kAlternativeMask = 500,
    kAlternativeViewTimelineWithInset = 501,
    kAnimation = 502,
    kAnimationRange = 503,
    kBackground = 504,
    kBackgroundPosition = 505,
    kBorder = 506,
    kBorderBlock = 507,
    kBorderBlockColor = 508,
    kBorderBlockEnd = 509,
    kBorderBlockStart = 510,
    kBorderBlockStyle = 511,
    kBorderBlockWidth = 512,
    kBorderBottom = 513,
    kBorderColor = 514,
    kBorderImage = 515,
    kBorderInline = 516,
    kBorderInlineColor = 517,
    kBorderInlineEnd = 518,
    kBorderInlineStart = 519,
    kBorderInlineStyle = 520,
    kBorderInlineWidth = 521,
    kBorderLeft = 522,
    kBorderRadius = 523,
    kBorderRight = 524,
    kBorderSpacing = 525,
    kBorderStyle = 526,
    kBorderTop = 527,
    kBorderWidth = 528,
    kColumnRule = 529,
    kColumns = 530,
    kContainIntrinsicSize = 531,
    kContainer = 532,
    kFlex = 533,
    kFlexFlow = 534,
    kFont = 535,
    kFontSynthesis = 536,
    kFontVariant = 537,
    kGap = 538,
    kGrid = 539,
    kGridArea = 540,
    kGridColumn = 541,
    kGridColumnGap = 542,
    kGridGap = 543,
    kGridRow = 544,
    kGridRowGap = 545,
    kGridTemplate = 546,
    kInset = 547,
    kInsetBlock = 548,
    kInsetInline = 549,
    kListStyle = 550,
    kMargin = 551,
    kMarginBlock = 552,
    kMarginInline = 553,
    kMarker = 554,
    kMaskPosition = 555,
    kOffset = 556,
    kOutline = 557,
    kOverflow = 558,
    kOverscrollBehavior = 559,
    kPadding = 560,
    kPaddingBlock = 561,
    kPaddingInline = 562,
    kPageBreakAfter = 563,
    kPageBreakBefore = 564,
    kPageBreakInside = 565,
    kPlaceContent = 566,
    kPlaceItems = 567,
    kPlaceSelf = 568,
    kPositionTry = 569,
    kScrollMargin = 570,
    kScrollMarginBlock = 571,
    kScrollMarginInline = 572,
    kScrollPadding = 573,
    kScrollPaddingBlock = 574,
    kScrollPaddingInline = 575,
    kScrollStart = 576,
    kScrollStartTarget = 577,
    kScrollTimeline = 578,
    kTextDecoration = 579,
    kTextEmphasis = 580,
    kTextSpacing = 581,
    kTransition = 582,
    kViewTimeline = 583,
    kWebkitColumnBreakAfter = 584,
    kWebkitColumnBreakBefore = 585,
    kWebkitColumnBreakInside = 586,
    kWebkitMask = 587,
    kWebkitMaskBoxImage = 588,
    kWebkitMaskPosition = 589,
    kWebkitTextStroke = 590,
    kWhiteSpace = 591,
    kAliasWebkitAppearance = 592,
    kAliasWebkitAppRegion = 593,
    kAliasWebkitAlternativeMaskClip = 594,
    kAliasWebkitAlternativeMaskComposite = 595,
    kAliasWebkitAlternativeMaskImage = 596,
    kAliasWebkitAlternativeMaskOrigin = 597,
    kAliasWebkitAlternativeMaskRepeat = 598,
    kAliasWebkitAlternativeMaskSize = 599,
    kAliasWebkitBorderEndColor = 600,
    kAliasWebkitBorderEndStyle = 601,
    kAliasWebkitBorderEndWidth = 602,
    kAliasWebkitBorderStartColor = 603,
    kAliasWebkitBorderStartStyle = 604,
    kAliasWebkitBorderStartWidth = 605,
    kAliasWebkitBorderBeforeColor = 606,
    kAliasWebkitBorderBeforeStyle = 607,
    kAliasWebkitBorderBeforeWidth = 608,
    kAliasWebkitBorderAfterColor = 609,
    kAliasWebkitBorderAfterStyle = 610,
    kAliasWebkitBorderAfterWidth = 611,
    kAliasWebkitMarginEnd = 612,
    kAliasWebkitMarginStart = 613,
    kAliasWebkitMarginBefore = 614,
    kAliasWebkitMarginAfter = 615,
    kAliasWebkitPaddingEnd = 616,
    kAliasWebkitPaddingStart = 617,
    kAliasWebkitPaddingBefore = 618,
    kAliasWebkitPaddingAfter = 619,
    kAliasWebkitLogicalWidth = 620,
    kAliasWebkitLogicalHeight = 621,
    kAliasWebkitMinLogicalWidth = 622,
    kAliasWebkitMinLogicalHeight = 623,
    kAliasWebkitMaxLogicalWidth = 624,
    kAliasWebkitMaxLogicalHeight = 625,
    kAliasWebkitBorderAfter = 626,
    kAliasWebkitBorderBefore = 627,
    kAliasWebkitBorderEnd = 628,
    kAliasWebkitBorderStart = 629,
    kAliasWebkitAlternativeMask = 630,
    kAliasWebkitAlternativeMaskPosition = 631,
    kAliasEpubCaptionSide = 632,
    kAliasEpubTextCombine = 633,
    kAliasEpubTextEmphasis = 634,
    kAliasEpubTextEmphasisColor = 635,
    kAliasEpubTextEmphasisStyle = 636,
    kAliasEpubTextOrientation = 637,
    kAliasEpubTextTransform = 638,
    kAliasEpubWordBreak = 639,
    kAliasEpubWritingMode = 640,
    kAliasWebkitAlignContent = 641,
    kAliasWebkitAlignItems = 642,
    kAliasWebkitAlignSelf = 643,
    kAliasWebkitAnimation = 644,
    kAliasWebkitAlternativeAnimationWithTimeline = 645,
    kAliasWebkitAlternativeAnimationWithDelayStartEnd = 646,
    kAliasWebkitAnimationDelay = 647,
    kAliasWebkitAlternativeAnimationDelay = 648,
    kAliasWebkitAnimationDirection = 649,
    kAliasWebkitAnimationDuration = 650,
    kAliasWebkitAnimationFillMode = 651,
    kAliasWebkitAnimationIterationCount = 652,
    kAliasWebkitAnimationName = 653,
    kAliasWebkitAnimationPlayState = 654,
    kAliasWebkitAnimationTimingFunction = 655,
    kAliasWebkitBackfaceVisibility = 656,
    kAliasWebkitBackgroundClip = 657,
    kAliasWebkitBackgroundOrigin = 658,
    kAliasWebkitBackgroundSize = 659,
    kAliasWebkitBorderBottomLeftRadius = 660,
    kAliasWebkitBorderBottomRightRadius = 661,
    kAliasWebkitBorderRadius = 662,
    kAliasWebkitBorderTopLeftRadius = 663,
    kAliasWebkitBorderTopRightRadius = 664,
    kAliasWebkitBoxShadow = 665,
    kAliasWebkitBoxSizing = 666,
    kAliasWebkitClipPath = 667,
    kAliasWebkitColumnCount = 668,
    kAliasWebkitColumnGap = 669,
    kAliasWebkitColumnRule = 670,
    kAliasWebkitColumnRuleColor = 671,
    kAliasWebkitColumnRuleStyle = 672,
    kAliasWebkitColumnRuleWidth = 673,
    kAliasWebkitColumnSpan = 674,
    kAliasWebkitColumnWidth = 675,
    kAliasWebkitColumns = 676,
    kAliasWebkitFilter = 677,
    kAliasWebkitFlex = 678,
    kAliasWebkitFlexBasis = 679,
    kAliasWebkitFlexDirection = 680,
    kAliasWebkitFlexFlow = 681,
    kAliasWebkitFlexGrow = 682,
    kAliasWebkitFlexShrink = 683,
    kAliasWebkitFlexWrap = 684,
    kAliasWebkitFontFeatureSettings = 685,
    kAliasWebkitHyphenateCharacter = 686,
    kAliasWebkitJustifyContent = 687,
    kAliasWebkitOpacity = 688,
    kAliasWebkitOrder = 689,
    kAliasWebkitPerspective = 690,
    kAliasWebkitPerspectiveOrigin = 691,
    kAliasWebkitShapeImageThreshold = 692,
    kAliasWebkitShapeMargin = 693,
    kAliasWebkitShapeOutside = 694,
    kAliasWebkitTextEmphasis = 695,
    kAliasWebkitTextEmphasisColor = 696,
    kAliasWebkitTextEmphasisPosition = 697,
    kAliasWebkitTextEmphasisStyle = 698,
    kAliasWebkitTextSizeAdjust = 699,
    kAliasWebkitTransform = 700,
    kAliasWebkitTransformOrigin = 701,
    kAliasWebkitTransformStyle = 702,
    kAliasWebkitTransition = 703,
    kAliasWebkitTransitionDelay = 704,
    kAliasWebkitTransitionDuration = 705,
    kAliasWebkitTransitionProperty = 706,
    kAliasWebkitTransitionTimingFunction = 707,
    kAliasWebkitUserSelect = 708,
    kAliasWordWrap = 709,
};

const CSSPropertyID kCSSPropertyAliasList[] = {
    CSSPropertyID::kAliasWebkitAppearance,
    CSSPropertyID::kAliasWebkitAppRegion,
    CSSPropertyID::kAliasWebkitAlternativeMaskClip,
    CSSPropertyID::kAliasWebkitAlternativeMaskComposite,
    CSSPropertyID::kAliasWebkitAlternativeMaskImage,
    CSSPropertyID::kAliasWebkitAlternativeMaskOrigin,
    CSSPropertyID::kAliasWebkitAlternativeMaskRepeat,
    CSSPropertyID::kAliasWebkitAlternativeMaskSize,
    CSSPropertyID::kAliasWebkitBorderEndColor,
    CSSPropertyID::kAliasWebkitBorderEndStyle,
    CSSPropertyID::kAliasWebkitBorderEndWidth,
    CSSPropertyID::kAliasWebkitBorderStartColor,
    CSSPropertyID::kAliasWebkitBorderStartStyle,
    CSSPropertyID::kAliasWebkitBorderStartWidth,
    CSSPropertyID::kAliasWebkitBorderBeforeColor,
    CSSPropertyID::kAliasWebkitBorderBeforeStyle,
    CSSPropertyID::kAliasWebkitBorderBeforeWidth,
    CSSPropertyID::kAliasWebkitBorderAfterColor,
    CSSPropertyID::kAliasWebkitBorderAfterStyle,
    CSSPropertyID::kAliasWebkitBorderAfterWidth,
    CSSPropertyID::kAliasWebkitMarginEnd,
    CSSPropertyID::kAliasWebkitMarginStart,
    CSSPropertyID::kAliasWebkitMarginBefore,
    CSSPropertyID::kAliasWebkitMarginAfter,
    CSSPropertyID::kAliasWebkitPaddingEnd,
    CSSPropertyID::kAliasWebkitPaddingStart,
    CSSPropertyID::kAliasWebkitPaddingBefore,
    CSSPropertyID::kAliasWebkitPaddingAfter,
    CSSPropertyID::kAliasWebkitLogicalWidth,
    CSSPropertyID::kAliasWebkitLogicalHeight,
    CSSPropertyID::kAliasWebkitMinLogicalWidth,
    CSSPropertyID::kAliasWebkitMinLogicalHeight,
    CSSPropertyID::kAliasWebkitMaxLogicalWidth,
    CSSPropertyID::kAliasWebkitMaxLogicalHeight,
    CSSPropertyID::kAliasWebkitBorderAfter,
    CSSPropertyID::kAliasWebkitBorderBefore,
    CSSPropertyID::kAliasWebkitBorderEnd,
    CSSPropertyID::kAliasWebkitBorderStart,
    CSSPropertyID::kAliasWebkitAlternativeMask,
    CSSPropertyID::kAliasWebkitAlternativeMaskPosition,
    CSSPropertyID::kAliasEpubCaptionSide,
    CSSPropertyID::kAliasEpubTextCombine,
    CSSPropertyID::kAliasEpubTextEmphasis,
    CSSPropertyID::kAliasEpubTextEmphasisColor,
    CSSPropertyID::kAliasEpubTextEmphasisStyle,
    CSSPropertyID::kAliasEpubTextOrientation,
    CSSPropertyID::kAliasEpubTextTransform,
    CSSPropertyID::kAliasEpubWordBreak,
    CSSPropertyID::kAliasEpubWritingMode,
    CSSPropertyID::kAliasWebkitAlignContent,
    CSSPropertyID::kAliasWebkitAlignItems,
    CSSPropertyID::kAliasWebkitAlignSelf,
    CSSPropertyID::kAliasWebkitAnimation,
    CSSPropertyID::kAliasWebkitAlternativeAnimationWithTimeline,
    CSSPropertyID::kAliasWebkitAlternativeAnimationWithDelayStartEnd,
    CSSPropertyID::kAliasWebkitAnimationDelay,
    CSSPropertyID::kAliasWebkitAlternativeAnimationDelay,
    CSSPropertyID::kAliasWebkitAnimationDirection,
    CSSPropertyID::kAliasWebkitAnimationDuration,
    CSSPropertyID::kAliasWebkitAnimationFillMode,
    CSSPropertyID::kAliasWebkitAnimationIterationCount,
    CSSPropertyID::kAliasWebkitAnimationName,
    CSSPropertyID::kAliasWebkitAnimationPlayState,
    CSSPropertyID::kAliasWebkitAnimationTimingFunction,
    CSSPropertyID::kAliasWebkitBackfaceVisibility,
    CSSPropertyID::kAliasWebkitBackgroundClip,
    CSSPropertyID::kAliasWebkitBackgroundOrigin,
    CSSPropertyID::kAliasWebkitBackgroundSize,
    CSSPropertyID::kAliasWebkitBorderBottomLeftRadius,
    CSSPropertyID::kAliasWebkitBorderBottomRightRadius,
    CSSPropertyID::kAliasWebkitBorderRadius,
    CSSPropertyID::kAliasWebkitBorderTopLeftRadius,
    CSSPropertyID::kAliasWebkitBorderTopRightRadius,
    CSSPropertyID::kAliasWebkitBoxShadow,
    CSSPropertyID::kAliasWebkitBoxSizing,
    CSSPropertyID::kAliasWebkitClipPath,
    CSSPropertyID::kAliasWebkitColumnCount,
    CSSPropertyID::kAliasWebkitColumnGap,
    CSSPropertyID::kAliasWebkitColumnRule,
    CSSPropertyID::kAliasWebkitColumnRuleColor,
    CSSPropertyID::kAliasWebkitColumnRuleStyle,
    CSSPropertyID::kAliasWebkitColumnRuleWidth,
    CSSPropertyID::kAliasWebkitColumnSpan,
    CSSPropertyID::kAliasWebkitColumnWidth,
    CSSPropertyID::kAliasWebkitColumns,
    CSSPropertyID::kAliasWebkitFilter,
    CSSPropertyID::kAliasWebkitFlex,
    CSSPropertyID::kAliasWebkitFlexBasis,
    CSSPropertyID::kAliasWebkitFlexDirection,
    CSSPropertyID::kAliasWebkitFlexFlow,
    CSSPropertyID::kAliasWebkitFlexGrow,
    CSSPropertyID::kAliasWebkitFlexShrink,
    CSSPropertyID::kAliasWebkitFlexWrap,
    CSSPropertyID::kAliasWebkitFontFeatureSettings,
    CSSPropertyID::kAliasWebkitHyphenateCharacter,
    CSSPropertyID::kAliasWebkitJustifyContent,
    CSSPropertyID::kAliasWebkitOpacity,
    CSSPropertyID::kAliasWebkitOrder,
    CSSPropertyID::kAliasWebkitPerspective,
    CSSPropertyID::kAliasWebkitPerspectiveOrigin,
    CSSPropertyID::kAliasWebkitShapeImageThreshold,
    CSSPropertyID::kAliasWebkitShapeMargin,
    CSSPropertyID::kAliasWebkitShapeOutside,
    CSSPropertyID::kAliasWebkitTextEmphasis,
    CSSPropertyID::kAliasWebkitTextEmphasisColor,
    CSSPropertyID::kAliasWebkitTextEmphasisPosition,
    CSSPropertyID::kAliasWebkitTextEmphasisStyle,
    CSSPropertyID::kAliasWebkitTextSizeAdjust,
    CSSPropertyID::kAliasWebkitTransform,
    CSSPropertyID::kAliasWebkitTransformOrigin,
    CSSPropertyID::kAliasWebkitTransformStyle,
    CSSPropertyID::kAliasWebkitTransition,
    CSSPropertyID::kAliasWebkitTransitionDelay,
    CSSPropertyID::kAliasWebkitTransitionDuration,
    CSSPropertyID::kAliasWebkitTransitionProperty,
    CSSPropertyID::kAliasWebkitTransitionTimingFunction,
    CSSPropertyID::kAliasWebkitUserSelect,
    CSSPropertyID::kAliasWordWrap,
};

const CSSPropertyID kCSSComputableProperties[] = {
    CSSPropertyID::kAccentColor,
    CSSPropertyID::kAlignContent,
    CSSPropertyID::kAlignItems,
    CSSPropertyID::kAlignSelf,
    CSSPropertyID::kAlignmentBaseline,
    CSSPropertyID::kAnchorName,
    CSSPropertyID::kAnimationComposition,
    CSSPropertyID::kAnimationDelay,
    CSSPropertyID::kAnimationDelayEnd,
    CSSPropertyID::kAnimationDelayStart,
    CSSPropertyID::kAnimationDirection,
    CSSPropertyID::kAnimationDuration,
    CSSPropertyID::kAnimationFillMode,
    CSSPropertyID::kAnimationIterationCount,
    CSSPropertyID::kAnimationName,
    CSSPropertyID::kAnimationPlayState,
    CSSPropertyID::kAnimationRangeEnd,
    CSSPropertyID::kAnimationRangeStart,
    CSSPropertyID::kAnimationTimeline,
    CSSPropertyID::kAnimationTimingFunction,
    CSSPropertyID::kAppRegion,
    CSSPropertyID::kAppearance,
    CSSPropertyID::kBackdropFilter,
    CSSPropertyID::kBackfaceVisibility,
    CSSPropertyID::kBackgroundAttachment,
    CSSPropertyID::kBackgroundBlendMode,
    CSSPropertyID::kBackgroundClip,
    CSSPropertyID::kBackgroundColor,
    CSSPropertyID::kBackgroundImage,
    CSSPropertyID::kBackgroundOrigin,
    CSSPropertyID::kBackgroundPosition,
    CSSPropertyID::kBackgroundRepeat,
    CSSPropertyID::kBackgroundSize,
    CSSPropertyID::kBaselineShift,
    CSSPropertyID::kBaselineSource,
    CSSPropertyID::kBlockSize,
    CSSPropertyID::kBorderBlockEndColor,
    CSSPropertyID::kBorderBlockEndStyle,
    CSSPropertyID::kBorderBlockEndWidth,
    CSSPropertyID::kBorderBlockStartColor,
    CSSPropertyID::kBorderBlockStartStyle,
    CSSPropertyID::kBorderBlockStartWidth,
    CSSPropertyID::kBorderBottomColor,
    CSSPropertyID::kBorderBottomLeftRadius,
    CSSPropertyID::kBorderBottomRightRadius,
    CSSPropertyID::kBorderBottomStyle,
    CSSPropertyID::kBorderBottomWidth,
    CSSPropertyID::kBorderCollapse,
    CSSPropertyID::kBorderEndEndRadius,
    CSSPropertyID::kBorderEndStartRadius,
    CSSPropertyID::kBorderImageOutset,
    CSSPropertyID::kBorderImageRepeat,
    CSSPropertyID::kBorderImageSlice,
    CSSPropertyID::kBorderImageSource,
    CSSPropertyID::kBorderImageWidth,
    CSSPropertyID::kBorderInlineEndColor,
    CSSPropertyID::kBorderInlineEndStyle,
    CSSPropertyID::kBorderInlineEndWidth,
    CSSPropertyID::kBorderInlineStartColor,
    CSSPropertyID::kBorderInlineStartStyle,
    CSSPropertyID::kBorderInlineStartWidth,
    CSSPropertyID::kBorderLeftColor,
    CSSPropertyID::kBorderLeftStyle,
    CSSPropertyID::kBorderLeftWidth,
    CSSPropertyID::kBorderRightColor,
    CSSPropertyID::kBorderRightStyle,
    CSSPropertyID::kBorderRightWidth,
    CSSPropertyID::kBorderStartEndRadius,
    CSSPropertyID::kBorderStartStartRadius,
    CSSPropertyID::kBorderTopColor,
    CSSPropertyID::kBorderTopLeftRadius,
    CSSPropertyID::kBorderTopRightRadius,
    CSSPropertyID::kBorderTopStyle,
    CSSPropertyID::kBorderTopWidth,
    CSSPropertyID::kBottom,
    CSSPropertyID::kBoxShadow,
    CSSPropertyID::kBoxSizing,
    CSSPropertyID::kBreakAfter,
    CSSPropertyID::kBreakBefore,
    CSSPropertyID::kBreakInside,
    CSSPropertyID::kBufferedRendering,
    CSSPropertyID::kCaptionSide,
    CSSPropertyID::kCaretColor,
    CSSPropertyID::kClear,
    CSSPropertyID::kClip,
    CSSPropertyID::kClipPath,
    CSSPropertyID::kClipRule,
    CSSPropertyID::kColor,
    CSSPropertyID::kColorInterpolation,
    CSSPropertyID::kColorInterpolationFilters,
    CSSPropertyID::kColorRendering,
    CSSPropertyID::kColumnCount,
    CSSPropertyID::kColumnGap,
    CSSPropertyID::kColumnRuleColor,
    CSSPropertyID::kColumnRuleStyle,
    CSSPropertyID::kColumnRuleWidth,
    CSSPropertyID::kColumnSpan,
    CSSPropertyID::kColumnWidth,
    CSSPropertyID::kContainIntrinsicBlockSize,
    CSSPropertyID::kContainIntrinsicHeight,
    CSSPropertyID::kContainIntrinsicInlineSize,
    CSSPropertyID::kContainIntrinsicSize,
    CSSPropertyID::kContainIntrinsicWidth,
    CSSPropertyID::kContainerName,
    CSSPropertyID::kContainerType,
    CSSPropertyID::kContent,
    CSSPropertyID::kCursor,
    CSSPropertyID::kCx,
    CSSPropertyID::kCy,
    CSSPropertyID::kD,
    CSSPropertyID::kDirection,
    CSSPropertyID::kDisplay,
    CSSPropertyID::kDominantBaseline,
    CSSPropertyID::kDynamicRangeLimit,
    CSSPropertyID::kEmptyCells,
    CSSPropertyID::kFieldSizing,
    CSSPropertyID::kFill,
    CSSPropertyID::kFillOpacity,
    CSSPropertyID::kFillRule,
    CSSPropertyID::kFilter,
    CSSPropertyID::kFlexBasis,
    CSSPropertyID::kFlexDirection,
    CSSPropertyID::kFlexGrow,
    CSSPropertyID::kFlexShrink,
    CSSPropertyID::kFlexWrap,
    CSSPropertyID::kFloat,
    CSSPropertyID::kFloodColor,
    CSSPropertyID::kFloodOpacity,
    CSSPropertyID::kFontFamily,
    CSSPropertyID::kFontKerning,
    CSSPropertyID::kFontOpticalSizing,
    CSSPropertyID::kFontPalette,
    CSSPropertyID::kFontSize,
    CSSPropertyID::kFontSizeAdjust,
    CSSPropertyID::kFontStretch,
    CSSPropertyID::kFontStyle,
    CSSPropertyID::kFontSynthesisSmallCaps,
    CSSPropertyID::kFontSynthesisStyle,
    CSSPropertyID::kFontSynthesisWeight,
    CSSPropertyID::kFontVariant,
    CSSPropertyID::kFontVariantAlternates,
    CSSPropertyID::kFontVariantCaps,
    CSSPropertyID::kFontVariantEastAsian,
    CSSPropertyID::kFontVariantLigatures,
    CSSPropertyID::kFontVariantNumeric,
    CSSPropertyID::kFontVariantPosition,
    CSSPropertyID::kFontWeight,
    CSSPropertyID::kGridAutoColumns,
    CSSPropertyID::kGridAutoFlow,
    CSSPropertyID::kGridAutoRows,
    CSSPropertyID::kGridColumnEnd,
    CSSPropertyID::kGridColumnStart,
    CSSPropertyID::kGridRowEnd,
    CSSPropertyID::kGridRowStart,
    CSSPropertyID::kGridTemplateAreas,
    CSSPropertyID::kGridTemplateColumns,
    CSSPropertyID::kGridTemplateRows,
    CSSPropertyID::kHeight,
    CSSPropertyID::kHyphenateCharacter,
    CSSPropertyID::kHyphenateLimitChars,
    CSSPropertyID::kHyphens,
    CSSPropertyID::kImageOrientation,
    CSSPropertyID::kImageRendering,
    CSSPropertyID::kInitialLetter,
    CSSPropertyID::kInlineSize,
    CSSPropertyID::kInsetArea,
    CSSPropertyID::kInsetBlockEnd,
    CSSPropertyID::kInsetBlockStart,
    CSSPropertyID::kInsetInlineEnd,
    CSSPropertyID::kInsetInlineStart,
    CSSPropertyID::kIsolation,
    CSSPropertyID::kJustifyContent,
    CSSPropertyID::kJustifyItems,
    CSSPropertyID::kJustifySelf,
    CSSPropertyID::kLeft,
    CSSPropertyID::kLetterSpacing,
    CSSPropertyID::kLightingColor,
    CSSPropertyID::kLineBreak,
    CSSPropertyID::kLineHeight,
    CSSPropertyID::kListStyleImage,
    CSSPropertyID::kListStylePosition,
    CSSPropertyID::kListStyleType,
    CSSPropertyID::kMarginBlockEnd,
    CSSPropertyID::kMarginBlockStart,
    CSSPropertyID::kMarginBottom,
    CSSPropertyID::kMarginInlineEnd,
    CSSPropertyID::kMarginInlineStart,
    CSSPropertyID::kMarginLeft,
    CSSPropertyID::kMarginRight,
    CSSPropertyID::kMarginTop,
    CSSPropertyID::kMarkerEnd,
    CSSPropertyID::kMarkerMid,
    CSSPropertyID::kMarkerStart,
    CSSPropertyID::kMaskClip,
    CSSPropertyID::kMaskComposite,
    CSSPropertyID::kMaskImage,
    CSSPropertyID::kMaskMode,
    CSSPropertyID::kMaskOrigin,
    CSSPropertyID::kMaskPosition,
    CSSPropertyID::kMaskRepeat,
    CSSPropertyID::kMaskSize,
    CSSPropertyID::kMaskType,
    CSSPropertyID::kMathDepth,
    CSSPropertyID::kMathShift,
    CSSPropertyID::kMathStyle,
    CSSPropertyID::kMaxBlockSize,
    CSSPropertyID::kMaxHeight,
    CSSPropertyID::kMaxInlineSize,
    CSSPropertyID::kMaxWidth,
    CSSPropertyID::kMinBlockSize,
    CSSPropertyID::kMinHeight,
    CSSPropertyID::kMinInlineSize,
    CSSPropertyID::kMinWidth,
    CSSPropertyID::kMixBlendMode,
    CSSPropertyID::kObjectFit,
    CSSPropertyID::kObjectPosition,
    CSSPropertyID::kObjectViewBox,
    CSSPropertyID::kOffsetAnchor,
    CSSPropertyID::kOffsetDistance,
    CSSPropertyID::kOffsetPath,
    CSSPropertyID::kOffsetPosition,
    CSSPropertyID::kOffsetRotate,
    CSSPropertyID::kOpacity,
    CSSPropertyID::kOrder,
    CSSPropertyID::kOrphans,
    CSSPropertyID::kOutlineColor,
    CSSPropertyID::kOutlineOffset,
    CSSPropertyID::kOutlineStyle,
    CSSPropertyID::kOutlineWidth,
    CSSPropertyID::kOverflowAnchor,
    CSSPropertyID::kOverflowBlock,
    CSSPropertyID::kOverflowClipMargin,
    CSSPropertyID::kOverflowInline,
    CSSPropertyID::kOverflowWrap,
    CSSPropertyID::kOverflowX,
    CSSPropertyID::kOverflowY,
    CSSPropertyID::kOverlay,
    CSSPropertyID::kOverscrollBehaviorBlock,
    CSSPropertyID::kOverscrollBehaviorInline,
    CSSPropertyID::kPaddingBlockEnd,
    CSSPropertyID::kPaddingBlockStart,
    CSSPropertyID::kPaddingBottom,
    CSSPropertyID::kPaddingInlineEnd,
    CSSPropertyID::kPaddingInlineStart,
    CSSPropertyID::kPaddingLeft,
    CSSPropertyID::kPaddingRight,
    CSSPropertyID::kPaddingTop,
    CSSPropertyID::kPaintOrder,
    CSSPropertyID::kPerspective,
    CSSPropertyID::kPerspectiveOrigin,
    CSSPropertyID::kPointerEvents,
    CSSPropertyID::kPopoverHideDelay,
    CSSPropertyID::kPopoverShowDelay,
    CSSPropertyID::kPosition,
    CSSPropertyID::kPositionAnchor,
    CSSPropertyID::kPositionFallbackBounds,
    CSSPropertyID::kPositionTryOptions,
    CSSPropertyID::kPositionTryOrder,
    CSSPropertyID::kR,
    CSSPropertyID::kReadingOrderItems,
    CSSPropertyID::kResize,
    CSSPropertyID::kRight,
    CSSPropertyID::kRotate,
    CSSPropertyID::kRowGap,
    CSSPropertyID::kRubyPosition,
    CSSPropertyID::kRx,
    CSSPropertyID::kRy,
    CSSPropertyID::kScale,
    CSSPropertyID::kScrollBehavior,
    CSSPropertyID::kScrollMarginBlockEnd,
    CSSPropertyID::kScrollMarginBlockStart,
    CSSPropertyID::kScrollMarginInlineEnd,
    CSSPropertyID::kScrollMarginInlineStart,
    CSSPropertyID::kScrollPaddingBlockEnd,
    CSSPropertyID::kScrollPaddingBlockStart,
    CSSPropertyID::kScrollPaddingInlineEnd,
    CSSPropertyID::kScrollPaddingInlineStart,
    CSSPropertyID::kScrollStartBlock,
    CSSPropertyID::kScrollStartInline,
    CSSPropertyID::kScrollStartTargetBlock,
    CSSPropertyID::kScrollStartTargetInline,
    CSSPropertyID::kScrollStartTargetX,
    CSSPropertyID::kScrollStartTargetY,
    CSSPropertyID::kScrollStartX,
    CSSPropertyID::kScrollStartY,
    CSSPropertyID::kScrollTimelineAxis,
    CSSPropertyID::kScrollTimelineName,
    CSSPropertyID::kScrollbarColor,
    CSSPropertyID::kScrollbarGutter,
    CSSPropertyID::kScrollbarWidth,
    CSSPropertyID::kShapeImageThreshold,
    CSSPropertyID::kShapeMargin,
    CSSPropertyID::kShapeOutside,
    CSSPropertyID::kShapeRendering,
    CSSPropertyID::kSpeak,
    CSSPropertyID::kStopColor,
    CSSPropertyID::kStopOpacity,
    CSSPropertyID::kStroke,
    CSSPropertyID::kStrokeDasharray,
    CSSPropertyID::kStrokeDashoffset,
    CSSPropertyID::kStrokeLinecap,
    CSSPropertyID::kStrokeLinejoin,
    CSSPropertyID::kStrokeMiterlimit,
    CSSPropertyID::kStrokeOpacity,
    CSSPropertyID::kStrokeWidth,
    CSSPropertyID::kTabSize,
    CSSPropertyID::kTableLayout,
    CSSPropertyID::kTextAlign,
    CSSPropertyID::kTextAlignLast,
    CSSPropertyID::kTextAnchor,
    CSSPropertyID::kTextAutospace,
    CSSPropertyID::kTextBoxEdge,
    CSSPropertyID::kTextBoxTrim,
    CSSPropertyID::kTextDecoration,
    CSSPropertyID::kTextDecorationColor,
    CSSPropertyID::kTextDecorationLine,
    CSSPropertyID::kTextDecorationSkipInk,
    CSSPropertyID::kTextDecorationStyle,
    CSSPropertyID::kTextEmphasisColor,
    CSSPropertyID::kTextEmphasisPosition,
    CSSPropertyID::kTextEmphasisStyle,
    CSSPropertyID::kTextIndent,
    CSSPropertyID::kTextOverflow,
    CSSPropertyID::kTextRendering,
    CSSPropertyID::kTextShadow,
    CSSPropertyID::kTextSizeAdjust,
    CSSPropertyID::kTextSpacingTrim,
    CSSPropertyID::kTextTransform,
    CSSPropertyID::kTextUnderlinePosition,
    CSSPropertyID::kTextWrap,
    CSSPropertyID::kTimelineScope,
    CSSPropertyID::kTop,
    CSSPropertyID::kTouchAction,
    CSSPropertyID::kTransform,
    CSSPropertyID::kTransformOrigin,
    CSSPropertyID::kTransformStyle,
    CSSPropertyID::kTransitionBehavior,
    CSSPropertyID::kTransitionDelay,
    CSSPropertyID::kTransitionDuration,
    CSSPropertyID::kTransitionProperty,
    CSSPropertyID::kTransitionTimingFunction,
    CSSPropertyID::kTranslate,
    CSSPropertyID::kUnicodeBidi,
    CSSPropertyID::kUserSelect,
    CSSPropertyID::kVectorEffect,
    CSSPropertyID::kVerticalAlign,
    CSSPropertyID::kViewTimelineAxis,
    CSSPropertyID::kViewTimelineInset,
    CSSPropertyID::kViewTimelineName,
    CSSPropertyID::kViewTransitionClass,
    CSSPropertyID::kViewTransitionName,
    CSSPropertyID::kVisibility,
    CSSPropertyID::kWhiteSpaceCollapse,
    CSSPropertyID::kWidows,
    CSSPropertyID::kWidth,
    CSSPropertyID::kWillChange,
    CSSPropertyID::kWordBreak,
    CSSPropertyID::kWordSpacing,
    CSSPropertyID::kWritingMode,
    CSSPropertyID::kX,
    CSSPropertyID::kY,
    CSSPropertyID::kZIndex,
    CSSPropertyID::kZoom,
    CSSPropertyID::kWebkitBorderHorizontalSpacing,
    CSSPropertyID::kWebkitBorderImage,
    CSSPropertyID::kWebkitBorderVerticalSpacing,
    CSSPropertyID::kWebkitBoxAlign,
    CSSPropertyID::kWebkitBoxDecorationBreak,
    CSSPropertyID::kWebkitBoxDirection,
    CSSPropertyID::kWebkitBoxFlex,
    CSSPropertyID::kWebkitBoxOrdinalGroup,
    CSSPropertyID::kWebkitBoxOrient,
    CSSPropertyID::kWebkitBoxPack,
    CSSPropertyID::kWebkitBoxReflect,
    CSSPropertyID::kWebkitFontSmoothing,
    CSSPropertyID::kWebkitLineBreak,
    CSSPropertyID::kWebkitLineClamp,
    CSSPropertyID::kWebkitLocale,
    CSSPropertyID::kWebkitMaskBoxImage,
    CSSPropertyID::kWebkitMaskBoxImageOutset,
    CSSPropertyID::kWebkitMaskBoxImageRepeat,
    CSSPropertyID::kWebkitMaskBoxImageSlice,
    CSSPropertyID::kWebkitMaskBoxImageSource,
    CSSPropertyID::kWebkitMaskBoxImageWidth,
    CSSPropertyID::kWebkitMaskClip,
    CSSPropertyID::kWebkitMaskComposite,
    CSSPropertyID::kWebkitMaskImage,
    CSSPropertyID::kWebkitMaskOrigin,
    CSSPropertyID::kWebkitMaskPosition,
    CSSPropertyID::kWebkitMaskRepeat,
    CSSPropertyID::kWebkitMaskSize,
    CSSPropertyID::kWebkitPrintColorAdjust,
    CSSPropertyID::kWebkitRtlOrdering,
    CSSPropertyID::kWebkitTapHighlightColor,
    CSSPropertyID::kWebkitTextCombine,
    CSSPropertyID::kWebkitTextDecorationsInEffect,
    CSSPropertyID::kWebkitTextFillColor,
    CSSPropertyID::kWebkitTextOrientation,
    CSSPropertyID::kWebkitTextSecurity,
    CSSPropertyID::kWebkitTextStrokeColor,
    CSSPropertyID::kWebkitTextStrokeWidth,
    CSSPropertyID::kWebkitUserDrag,
    CSSPropertyID::kWebkitUserModify,
    CSSPropertyID::kWebkitWritingMode,
};

// The lowest CSSPropertyID excluding kInvalid and kVariable.
const int kIntFirstCSSProperty = 2;
const CSSPropertyID kFirstCSSProperty =
    static_cast<CSSPropertyID>(kIntFirstCSSProperty);

// The number of unresolved CSS properties excluding kInvalid and kVariable.
const int kNumCSSProperties = 708;

// The highest resolved CSSPropertyID.
const int kIntLastCSSProperty = 591;
const CSSPropertyID kLastCSSProperty =
    static_cast<CSSPropertyID>(kIntLastCSSProperty);

// The highest unresolved CSSPropertyID.
const CSSPropertyID kLastUnresolvedCSSProperty =
    static_cast<CSSPropertyID>(709);

const CSSPropertyID kFirstHighPriorityCSSProperty = kFirstCSSProperty;
const CSSPropertyID kLastHighPriorityCSSProperty = CSSPropertyID::kZoom;

// 1 + <The highest unresolved CSSPropertyID>.
const int kNumCSSPropertyIDs = static_cast<int>(kLastUnresolvedCSSProperty) + 1;

const size_t kMaxCSSPropertyNameLength = 48;
constexpr size_t kCSSPropertyIDBitLength = 10;
constexpr size_t kMaxShorthandExpansion = 17;

static_assert((static_cast<size_t>(1) << kCSSPropertyIDBitLength) >
                  static_cast<size_t>(kLastUnresolvedCSSProperty),
              "kCSSPropertyIDBitLength has enough bits");

// These are basically just change-detector tests, so that we do not
// accidentally add new high-priority properties or break the code generator.
static_assert(CSSPropertyID::kColorScheme == kFirstHighPriorityCSSProperty);
static_assert(CSSPropertyID::kZoom == kLastHighPriorityCSSProperty);
static_assert((static_cast<int>(kLastHighPriorityCSSProperty) -
               static_cast<int>(kFirstHighPriorityCSSProperty)) == 37,
              "There should a low number of high-priority properties");

inline int GetCSSPropertyIDIndex(CSSPropertyID id) {
    DCHECK_GE(id, kFirstCSSProperty);
    DCHECK_LE(id, kLastCSSProperty);
    return static_cast<int>(id) - kIntFirstCSSProperty;
}

constexpr bool IsHighPriority(CSSPropertyID id) {
  return id >= kFirstHighPriorityCSSProperty &&
      id <= kLastHighPriorityCSSProperty;
}

inline bool IsCSSPropertyIDWithName(CSSPropertyID id)
{
    return id >= kFirstCSSProperty && id <= kLastUnresolvedCSSProperty;
}

inline bool IsValidCSSPropertyID(CSSPropertyID id)
{
    return id != CSSPropertyID::kInvalid;
}

inline CSSPropertyID ConvertToCSSPropertyID(int value)
{
    DCHECK_GE(value, static_cast<int>(CSSPropertyID::kInvalid));
    DCHECK_LE(value, kIntLastCSSProperty);
    return static_cast<CSSPropertyID>(value);
}

int CORE_EXPORT ResolveCSSPropertyAlias(int value);

inline bool IsPropertyAlias(CSSPropertyID id) {
  return static_cast<int>(id) >= 592;
}

inline CSSPropertyID ResolveCSSPropertyID(CSSPropertyID id)
{
  int int_id = static_cast<int>(id);
  if (IsPropertyAlias(id))
    int_id = ResolveCSSPropertyAlias(int_id);
  return ConvertToCSSPropertyID(int_id);
}

CSSPropertyID CORE_EXPORT CssPropertyID(const ExecutionContext*,
                                        const WTF::String&);

class CSSPropertyIDList {
  STACK_ALLOCATED();

 public:
  class Iterator {
    STACK_ALLOCATED();
   public:
    Iterator(int id) : id_(id) {}
    CSSPropertyID operator*() const { return ConvertToCSSPropertyID(id_); }
    Iterator& operator++() {
      id_++;
      return *this;
    }
    bool operator!=(const Iterator& i) const { return id_ != i.id_; }

   private:
    int id_;
  };
  Iterator begin() const { return Iterator(kIntFirstCSSProperty); }
  Iterator end() const { return Iterator(kIntLastCSSProperty + 1); }
};

mojom::blink::CSSSampleId CORE_EXPORT GetCSSSampleId(CSSPropertyID id);

}  // namespace blink

#endif  // THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
