// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef THIRD_PARTY_BLINK_RENDERER_CORE_CSS_VALUE_KEYWORDS_H_
#define THIRD_PARTY_BLINK_RENDERER_CORE_CSS_VALUE_KEYWORDS_H_

#include <string.h>
#include <stdint.h>

#include "third_party/blink/renderer/core/core_export.h"
#include "third_party/blink/renderer/core/css/parser/css_parser_mode.h"

namespace blink {

enum class CSSValueID {
  kInvalid = 0,
  kInherit = 1,
  kInitial = 2,
  kNone = 3,
  kHidden = 4,
  kInset = 5,
  kGroove = 6,
  kOutset = 7,
  kRidge = 8,
  kDotted = 9,
  kDashed = 10,
  kSolid = 11,
  kDouble = 12,
  kCaption = 13,
  kIcon = 14,
  kMenu = 15,
  kMessageBox = 16,
  kSmallCaption = 17,
  kWebkitMiniControl = 18,
  kWebkitSmallControl = 19,
  kWebkitControl = 20,
  kStatusBar = 21,
  kItalic = 22,
  kOblique = 23,
  kAll = 24,
  kCommonLigatures = 25,
  kNoCommonLigatures = 26,
  kDiscretionaryLigatures = 27,
  kNoDiscretionaryLigatures = 28,
  kHistoricalLigatures = 29,
  kNoHistoricalLigatures = 30,
  kContextual = 31,
  kNoContextual = 32,
  kSmallCaps = 33,
  kAllSmallCaps = 34,
  kPetiteCaps = 35,
  kAllPetiteCaps = 36,
  kUnicase = 37,
  kTitlingCaps = 38,
  kJis78 = 39,
  kJis83 = 40,
  kJis90 = 41,
  kJis04 = 42,
  kSimplified = 43,
  kTraditional = 44,
  kFullWidth = 45,
  kProportionalWidth = 46,
  kRuby = 47,
  kLiningNums = 48,
  kOldstyleNums = 49,
  kProportionalNums = 50,
  kTabularNums = 51,
  kDiagonalFractions = 52,
  kStackedFractions = 53,
  kOrdinal = 54,
  kSlashedZero = 55,
  kStylistic = 56,
  kHistoricalForms = 57,
  kStyleset = 58,
  kCharacterVariant = 59,
  kSwash = 60,
  kOrnaments = 61,
  kAnnotation = 62,
  kNormal = 63,
  kBold = 64,
  kBolder = 65,
  kLighter = 66,
  kWeight = 67,
  kUltraCondensed = 68,
  kExtraCondensed = 69,
  kCondensed = 70,
  kSemiCondensed = 71,
  kSemiExpanded = 72,
  kExpanded = 73,
  kExtraExpanded = 74,
  kUltraExpanded = 75,
  kXxSmall = 76,
  kXSmall = 77,
  kSmall = 78,
  kMedium = 79,
  kLarge = 80,
  kXLarge = 81,
  kXxLarge = 82,
  kXxxLarge = 83,
  kSmaller = 84,
  kLarger = 85,
  kWebkitXxxLarge = 86,
  kExHeight = 87,
  kCapHeight = 88,
  kChWidth = 89,
  kIcWidth = 90,
  kSerif = 91,
  kSansSerif = 92,
  kCursive = 93,
  kFantasy = 94,
  kMonospace = 95,
  kSystemUi = 96,
  kWebkitBody = 97,
  kMath = 98,
  kSwap = 99,
  kFallback = 100,
  kOptional = 101,
  kFontTech = 102,
  kFontFormat = 103,
  kPaletteMix = 104,
  kAqua = 105,
  kBlack = 106,
  kBlue = 107,
  kFuchsia = 108,
  kGray = 109,
  kGreen = 110,
  kLime = 111,
  kMaroon = 112,
  kNavy = 113,
  kOlive = 114,
  kOrange = 115,
  kPurple = 116,
  kRed = 117,
  kSilver = 118,
  kTeal = 119,
  kWhite = 120,
  kYellow = 121,
  kTransparent = 122,
  kWebkitLink = 123,
  kWebkitActivelink = 124,
  kAccentcolor = 125,
  kAccentcolortext = 126,
  kActiveborder = 127,
  kActivecaption = 128,
  kActivetext = 129,
  kAppworkspace = 130,
  kBackground = 131,
  kButtonborder = 132,
  kButtonface = 133,
  kButtonhighlight = 134,
  kButtonshadow = 135,
  kButtontext = 136,
  kCanvas = 137,
  kCanvastext = 138,
  kCaptiontext = 139,
  kField = 140,
  kFieldtext = 141,
  kGraytext = 142,
  kHighlight = 143,
  kHighlighttext = 144,
  kInactiveborder = 145,
  kInactivecaption = 146,
  kInactivecaptiontext = 147,
  kInfobackground = 148,
  kInfotext = 149,
  kLinktext = 150,
  kMark = 151,
  kMarktext = 152,
  kMenutext = 153,
  kSelecteditem = 154,
  kSelecteditemtext = 155,
  kScrollbar = 156,
  kThreeddarkshadow = 157,
  kThreedface = 158,
  kThreedhighlight = 159,
  kThreedlightshadow = 160,
  kThreedshadow = 161,
  kVisitedtext = 162,
  kWindow = 163,
  kWindowframe = 164,
  kWindowtext = 165,
  kInternalActiveListBoxSelection = 166,
  kInternalActiveListBoxSelectionText = 167,
  kInternalInactiveListBoxSelection = 168,
  kInternalInactiveListBoxSelectionText = 169,
  kWebkitFocusRingColor = 170,
  kCurrentcolor = 171,
  kGrey = 172,
  kInternalQuirkInherit = 173,
  kInternalSpellingErrorColor = 174,
  kInternalGrammarErrorColor = 175,
  kAliceblue = 176,
  kAntiquewhite = 177,
  kAquamarine = 178,
  kAzure = 179,
  kBeige = 180,
  kBisque = 181,
  kBlanchedalmond = 182,
  kBlueviolet = 183,
  kBrown = 184,
  kBurlywood = 185,
  kCadetblue = 186,
  kChartreuse = 187,
  kChocolate = 188,
  kCoral = 189,
  kCornflowerblue = 190,
  kCornsilk = 191,
  kCrimson = 192,
  kCyan = 193,
  kDarkblue = 194,
  kDarkcyan = 195,
  kDarkgoldenrod = 196,
  kDarkgray = 197,
  kDarkgreen = 198,
  kDarkgrey = 199,
  kDarkkhaki = 200,
  kDarkmagenta = 201,
  kDarkolivegreen = 202,
  kDarkorange = 203,
  kDarkorchid = 204,
  kDarkred = 205,
  kDarksalmon = 206,
  kDarkseagreen = 207,
  kDarkslateblue = 208,
  kDarkslategray = 209,
  kDarkslategrey = 210,
  kDarkturquoise = 211,
  kDarkviolet = 212,
  kDeeppink = 213,
  kDeepskyblue = 214,
  kDimgray = 215,
  kDimgrey = 216,
  kDodgerblue = 217,
  kFirebrick = 218,
  kFloralwhite = 219,
  kForestgreen = 220,
  kGainsboro = 221,
  kGhostwhite = 222,
  kGold = 223,
  kGoldenrod = 224,
  kGreenyellow = 225,
  kHoneydew = 226,
  kHotpink = 227,
  kIndianred = 228,
  kIndigo = 229,
  kIvory = 230,
  kKhaki = 231,
  kLavender = 232,
  kLavenderblush = 233,
  kLawngreen = 234,
  kLemonchiffon = 235,
  kLightblue = 236,
  kLightcoral = 237,
  kLightcyan = 238,
  kLightgoldenrodyellow = 239,
  kLightgray = 240,
  kLightgreen = 241,
  kLightgrey = 242,
  kLightpink = 243,
  kLightsalmon = 244,
  kLightseagreen = 245,
  kLightskyblue = 246,
  kLightslategray = 247,
  kLightslategrey = 248,
  kLightsteelblue = 249,
  kLightyellow = 250,
  kLimegreen = 251,
  kLinen = 252,
  kMagenta = 253,
  kMediumaquamarine = 254,
  kMediumblue = 255,
  kMediumorchid = 256,
  kMediumpurple = 257,
  kMediumseagreen = 258,
  kMediumslateblue = 259,
  kMediumspringgreen = 260,
  kMediumturquoise = 261,
  kMediumvioletred = 262,
  kMidnightblue = 263,
  kMintcream = 264,
  kMistyrose = 265,
  kMoccasin = 266,
  kNavajowhite = 267,
  kOldlace = 268,
  kOlivedrab = 269,
  kOrangered = 270,
  kOrchid = 271,
  kPalegoldenrod = 272,
  kPalegreen = 273,
  kPaleturquoise = 274,
  kPalevioletred = 275,
  kPapayawhip = 276,
  kPeachpuff = 277,
  kPeru = 278,
  kPink = 279,
  kPlum = 280,
  kPowderblue = 281,
  kRebeccapurple = 282,
  kRosybrown = 283,
  kRoyalblue = 284,
  kSaddlebrown = 285,
  kSalmon = 286,
  kSandybrown = 287,
  kSeagreen = 288,
  kSeashell = 289,
  kSienna = 290,
  kSkyblue = 291,
  kSlateblue = 292,
  kSlategray = 293,
  kSlategrey = 294,
  kSnow = 295,
  kSpringgreen = 296,
  kSteelblue = 297,
  kTan = 298,
  kThistle = 299,
  kTomato = 300,
  kTurquoise = 301,
  kViolet = 302,
  kWheat = 303,
  kWhitesmoke = 304,
  kYellowgreen = 305,
  kRepeat = 306,
  kRepeatX = 307,
  kRepeatY = 308,
  kNoRepeat = 309,
  kClear = 310,
  kCopy = 311,
  kSourceOver = 312,
  kSourceIn = 313,
  kSourceOut = 314,
  kSourceAtop = 315,
  kDestinationOver = 316,
  kDestinationIn = 317,
  kDestinationOut = 318,
  kDestinationAtop = 319,
  kXor = 320,
  kPlusLighter = 321,
  kSubtract = 322,
  kIntersect = 323,
  kExclude = 324,
  kBaseline = 325,
  kMiddle = 326,
  kSub = 327,
  kSuper = 328,
  kTextTop = 329,
  kTextBottom = 330,
  kTop = 331,
  kBottom = 332,
  kWebkitBaselineMiddle = 333,
  kWebkitAuto = 334,
  kLeft = 335,
  kRight = 336,
  kCenter = 337,
  kJustify = 338,
  kWebkitLeft = 339,
  kWebkitRight = 340,
  kWebkitCenter = 341,
  kWebkitMatchParent = 342,
  kInternalCenter = 343,
  kInlineStart = 344,
  kInlineEnd = 345,
  kOutside = 346,
  kInside = 347,
  kDisc = 348,
  kCircle = 349,
  kSquare = 350,
  kDisclosureOpen = 351,
  kDisclosureClosed = 352,
  kDecimal = 353,
  kInline = 354,
  kBlock = 355,
  kFlowRoot = 356,
  kFlow = 357,
  kTable = 358,
  kFlex = 359,
  kGrid = 360,
  kContents = 361,
  kTableRowGroup = 362,
  kTableHeaderGroup = 363,
  kTableFooterGroup = 364,
  kTableRow = 365,
  kTableColumnGroup = 366,
  kTableColumn = 367,
  kTableCell = 368,
  kTableCaption = 369,
  kRubyText = 370,
  kInlineBlock = 371,
  kInlineTable = 372,
  kInlineFlex = 373,
  kInlineGrid = 374,
  kWebkitBox = 375,
  kWebkitInlineBox = 376,
  kWebkitFlex = 377,
  kWebkitInlineFlex = 378,
  kLayout = 379,
  kInlineLayout = 380,
  kListItem = 381,
  kAuto = 382,
  kCrosshair = 383,
  kDefault = 384,
  kPointer = 385,
  kMove = 386,
  kVerticalText = 387,
  kCell = 388,
  kContextMenu = 389,
  kAlias = 390,
  kProgress = 391,
  kNoDrop = 392,
  kNotAllowed = 393,
  kZoomIn = 394,
  kZoomOut = 395,
  kEResize = 396,
  kNeResize = 397,
  kNwResize = 398,
  kNResize = 399,
  kSeResize = 400,
  kSwResize = 401,
  kSResize = 402,
  kWResize = 403,
  kEwResize = 404,
  kNsResize = 405,
  kNeswResize = 406,
  kNwseResize = 407,
  kColResize = 408,
  kRowResize = 409,
  kText = 410,
  kWait = 411,
  kHelp = 412,
  kAllScroll = 413,
  kGrab = 414,
  kGrabbing = 415,
  kWebkitGrab = 416,
  kWebkitGrabbing = 417,
  kWebkitZoomIn = 418,
  kWebkitZoomOut = 419,
  kLtr = 420,
  kRtl = 421,
  kCapitalize = 422,
  kUppercase = 423,
  kLowercase = 424,
  kMathAuto = 425,
  kVisible = 426,
  kCollapse = 427,
  kPreserve = 428,
  kPreserveBreaks = 429,
  kPretty = 430,
  kA3 = 431,
  kA4 = 432,
  kA5 = 433,
  kAbove = 434,
  kAbsolute = 435,
  kAlways = 436,
  kAvoid = 437,
  kB4 = 438,
  kB5 = 439,
  kBelow = 440,
  kBidiOverride = 441,
  kBlink = 442,
  kBoth = 443,
  kBreakSpaces = 444,
  kCloseQuote = 445,
  kEmbed = 446,
  kFixed = 447,
  kHand = 448,
  kHide = 449,
  kIsolate = 450,
  kIsolateOverride = 451,
  kPlaintext = 452,
  kWebkitIsolate = 453,
  kWebkitIsolateOverride = 454,
  kWebkitPlaintext = 455,
  kJisB5 = 456,
  kJisB4 = 457,
  kLandscape = 458,
  kLedger = 459,
  kLegal = 460,
  kLetter = 461,
  kLineThrough = 462,
  kLocal = 463,
  kNoCloseQuote = 464,
  kNoOpenQuote = 465,
  kNowrap = 466,
  kOpenQuote = 467,
  kOverlay = 468,
  kOverline = 469,
  kPortrait = 470,
  kPre = 471,
  kPreLine = 472,
  kPreWrap = 473,
  kRelative = 474,
  kScroll = 475,
  kSeparate = 476,
  kShow = 477,
  kStatic = 478,
  kThick = 479,
  kThin = 480,
  kUnderline = 481,
  kView = 482,
  kWavy = 483,
  kCompact = 484,
  kStretch = 485,
  kStart = 486,
  kEnd = 487,
  kClone = 488,
  kSlice = 489,
  kReverse = 490,
  kHorizontal = 491,
  kVertical = 492,
  kInlineAxis = 493,
  kBlockAxis = 494,
  kFlexStart = 495,
  kFlexEnd = 496,
  kSpaceBetween = 497,
  kSpaceAround = 498,
  kSpaceEvenly = 499,
  kUnsafe = 500,
  kSafe = 501,
  kAnchorCenter = 502,
  kRow = 503,
  kRowReverse = 504,
  kColumn = 505,
  kColumnReverse = 506,
  kWrap = 507,
  kWrapReverse = 508,
  kAutoFlow = 509,
  kDense = 510,
  kReadOnly = 511,
  kReadWrite = 512,
  kReadWritePlaintextOnly = 513,
  kElement = 514,
  kWebkitMinContent = 515,
  kWebkitMaxContent = 516,
  kWebkitFillAvailable = 517,
  kWebkitFitContent = 518,
  kMinContent = 519,
  kMaxContent = 520,
  kFitContent = 521,
  kNoAutospace = 522,
  kCap = 523,
  kEx = 524,
  kLeading = 525,
  kClip = 526,
  kEllipsis = 527,
  kSpellingError = 528,
  kGrammarError = 529,
  kFromFont = 530,
  kSpaceAll = 531,
  kSpaceFirst = 532,
  kTrimStart = 533,
  kBreakAll = 534,
  kKeepAll = 535,
  kAutoPhrase = 536,
  kBreakWord = 537,
  kSpace = 538,
  kLoose = 539,
  kStrict = 540,
  kAfterWhiteSpace = 541,
  kAnywhere = 542,
  kManual = 543,
  kCheckbox = 544,
  kRadio = 545,
  kButton = 546,
  kListbox = 547,
  kInternalMediaControl = 548,
  kMenulist = 549,
  kMenulistButton = 550,
  kMeter = 551,
  kProgressBar = 552,
  kSearchfield = 553,
  kTextfield = 554,
  kTextarea = 555,
  kInnerSpinButton = 556,
  kPushButton = 557,
  kSquareButton = 558,
  kSliderHorizontal = 559,
  kSearchfieldCancelButton = 560,
  kMediaSlider = 561,
  kMediaSliderthumb = 562,
  kMediaVolumeSlider = 563,
  kMediaVolumeSliderthumb = 564,
  kSliderthumbHorizontal = 565,
  kSliderthumbVertical = 566,
  kSliderVertical = 567,
  kRound = 568,
  kBikeshed = 569,
  kBorder = 570,
  kBorderBox = 571,
  kContent = 572,
  kContentBox = 573,
  kPadding = 574,
  kPaddingBox = 575,
  kMarginBox = 576,
  kNoClip = 577,
  kContain = 578,
  kCover = 579,
  kLogical = 580,
  kVisual = 581,
  kReplace = 582,
  kAccumulate = 583,
  kAlternate = 584,
  kAlternateReverse = 585,
  kForwards = 586,
  kBackwards = 587,
  kInfinite = 588,
  kRunning = 589,
  kPaused = 590,
  kFlat = 591,
  kPreserve3d = 592,
  kFillBox = 593,
  kViewBox = 594,
  kEase = 595,
  kLinear = 596,
  kEaseIn = 597,
  kEaseOut = 598,
  kEaseInOut = 599,
  kJumpBoth = 600,
  kJumpEnd = 601,
  kJumpNone = 602,
  kJumpStart = 603,
  kStepStart = 604,
  kStepEnd = 605,
  kSteps = 606,
  kFrames = 607,
  kCubicBezier = 608,
  kDocument = 609,
  kReset = 610,
  kZoom = 611,
  kVisiblepainted = 612,
  kVisiblefill = 613,
  kVisiblestroke = 614,
  kPainted = 615,
  kFill = 616,
  kStroke = 617,
  kBoundingBox = 618,
  kSpellOut = 619,
  kDigits = 620,
  kLiteralPunctuation = 621,
  kNoPunctuation = 622,
  kAntialiased = 623,
  kSubpixelAntialiased = 624,
  kOptimizespeed = 625,
  kOptimizelegibility = 626,
  kGeometricprecision = 627,
  kCrispedges = 628,
  kEconomy = 629,
  kExact = 630,
  kLr = 631,
  kRl = 632,
  kTb = 633,
  kLrTb = 634,
  kRlTb = 635,
  kTbRl = 636,
  kHorizontalTb = 637,
  kVerticalRl = 638,
  kVerticalLr = 639,
  kAfter = 640,
  kBefore = 641,
  kOver = 642,
  kUnder = 643,
  kFilled = 644,
  kOpen = 645,
  kDot = 646,
  kDoubleCircle = 647,
  kTriangle = 648,
  kSesame = 649,
  kEllipse = 650,
  kClosestSide = 651,
  kClosestCorner = 652,
  kFarthestSide = 653,
  kFarthestCorner = 654,
  kMixed = 655,
  kSideways = 656,
  kSidewaysRight = 657,
  kUpright = 658,
  kVerticalRight = 659,
  kOn = 660,
  kOff = 661,
  kOptimizequality = 662,
  kPixelated = 663,
  kWebkitOptimizeContrast = 664,
  kFromImage = 665,
  kRotateLeft = 666,
  kRotateRight = 667,
  kNonzero = 668,
  kEvenodd = 669,
  kAt = 670,
  kAlphabetic = 671,
  kBorderless = 672,
  kFullscreen = 673,
  kStandalone = 674,
  kMinimalUi = 675,
  kBrowser = 676,
  kWindowControlsOverlay = 677,
  kTabbed = 678,
  kPictureInPicture = 679,
  kMinimized = 680,
  kMaximized = 681,
  kPaged = 682,
  kSlow = 683,
  kFast = 684,
  kSticky = 685,
  kCoarse = 686,
  kFine = 687,
  kOnDemand = 688,
  kHover = 689,
  kMultiply = 690,
  kScreen = 691,
  kDarken = 692,
  kLighten = 693,
  kColorDodge = 694,
  kColorBurn = 695,
  kHardLight = 696,
  kSoftLight = 697,
  kDifference = 698,
  kExclusion = 699,
  kHue = 700,
  kSaturation = 701,
  kColor = 702,
  kLuminosity = 703,
  kScaleDown = 704,
  kBalance = 705,
  kDrag = 706,
  kNoDrag = 707,
  kSpan = 708,
  kMinmax = 709,
  kSubgrid = 710,
  kProgressive = 711,
  kInterlace = 712,
  kMarkers = 713,
  kAlpha = 714,
  kLuminance = 715,
  kMatchSource = 716,
  kSRGB = 717,
  kLinearrgb = 718,
  kButt = 719,
  kMiter = 720,
  kBevel = 721,
  kBeforeEdge = 722,
  kAfterEdge = 723,
  kCentral = 724,
  kTextBeforeEdge = 725,
  kTextAfterEdge = 726,
  kIdeographic = 727,
  kHanging = 728,
  kMathematical = 729,
  kUseScript = 730,
  kNoChange = 731,
  kResetSize = 732,
  kDynamic = 733,
  kNonScalingStroke = 734,
  kInternalExtendToZoom = 735,
  kPanX = 736,
  kPanY = 737,
  kPanLeft = 738,
  kPanRight = 739,
  kPanUp = 740,
  kPanDown = 741,
  kManipulation = 742,
  kPinchZoom = 743,
  kLastBaseline = 744,
  kFirstBaseline = 745,
  kFirst = 746,
  kLast = 747,
  kSelfStart = 748,
  kSelfEnd = 749,
  kLegacy = 750,
  kSmooth = 751,
  kScrollPosition = 752,
  kRevert = 753,
  kRevertLayer = 754,
  kUnset = 755,
  kLinearGradient = 756,
  kRadialGradient = 757,
  kConicGradient = 758,
  kRepeatingLinearGradient = 759,
  kRepeatingRadialGradient = 760,
  kRepeatingConicGradient = 761,
  kPaint = 762,
  kCrossFade = 763,
  kWebkitCrossFade = 764,
  kWebkitGradient = 765,
  kWebkitLinearGradient = 766,
  kWebkitRadialGradient = 767,
  kWebkitRepeatingLinearGradient = 768,
  kWebkitRepeatingRadialGradient = 769,
  kWebkitImageSet = 770,
  kImageSet = 771,
  kType = 772,
  kTo = 773,
  kColorStop = 774,
  kRadial = 775,
  kAttr = 776,
  kCounter = 777,
  kCounters = 778,
  kRect = 779,
  kPolygon = 780,
  kFormat = 781,
  kCollection = 782,
  kEmbeddedOpentype = 783,
  kOpentype = 784,
  kSVG = 785,
  kTruetype = 786,
  kWoff = 787,
  kWoff2 = 788,
  kTech = 789,
  kFeaturesOpentype = 790,
  kFeaturesAat = 791,
  kFeaturesGraphite = 792,
  kColorCOLRv0 = 793,
  kColorCOLRv1 = 794,
  kColorSVG = 795,
  kColorSbix = 796,
  kColorCBDT = 797,
  kVariations = 798,
  kPalettes = 799,
  kIncremental = 800,
  kInvert = 801,
  kGrayscale = 802,
  kSepia = 803,
  kSaturate = 804,
  kHueRotate = 805,
  kOpacity = 806,
  kBrightness = 807,
  kContrast = 808,
  kBlur = 809,
  kDropShadow = 810,
  kUrl = 811,
  kRgb = 812,
  kRgba = 813,
  kHsl = 814,
  kHsla = 815,
  kHwb = 816,
  kLab = 817,
  kOklab = 818,
  kLch = 819,
  kOklch = 820,
  kLightDark = 821,
  kSRGBLinear = 822,
  kDisplayP3 = 823,
  kA98Rgb = 824,
  kProphotoRgb = 825,
  kXyz = 826,
  kXyzD50 = 827,
  kXyzD65 = 828,
  kShorter = 829,
  kLonger = 830,
  kDecreasing = 831,
  kIncreasing = 832,
  kIn = 833,
  kColorMix = 834,
  kFrom = 835,
  kR = 836,
  kG = 837,
  kB = 838,
  kH = 839,
  kS = 840,
  kL = 841,
  kW = 842,
  kA = 843,
  kC = 844,
  kMatrix = 845,
  kMatrix3d = 846,
  kPerspective = 847,
  kRotate = 848,
  kRotateX = 849,
  kRotateY = 850,
  kRotateZ = 851,
  kRotate3d = 852,
  kScale = 853,
  kScaleX = 854,
  kScaleY = 855,
  kScaleZ = 856,
  kScale3d = 857,
  kSkew = 858,
  kSkewX = 859,
  kSkewY = 860,
  kTranslate = 861,
  kTranslateX = 862,
  kTranslateY = 863,
  kTranslateZ = 864,
  kTranslate3d = 865,
  kX = 866,
  kY = 867,
  kZ = 868,
  kPath = 869,
  kRay = 870,
  kSides = 871,
  kStrokeBox = 872,
  kCalc = 873,
  kWebkitCalc = 874,
  kMin = 875,
  kMax = 876,
  kClamp = 877,
  kCalcSize = 878,
  kAny = 879,
  kSin = 880,
  kCos = 881,
  kAsin = 882,
  kAtan = 883,
  kAtan2 = 884,
  kAcos = 885,
  kMod = 886,
  kRem = 887,
  kUp = 888,
  kDown = 889,
  kToZero = 890,
  kSign = 891,
  kAbs = 892,
  kPow = 893,
  kSqrt = 894,
  kHypot = 895,
  kLog = 896,
  kExp = 897,
  kInfinity = 898,
  kNegativeInfinity = 899,
  kNan = 900,
  kPi = 901,
  kE = 902,
  kMandatory = 903,
  kProximity = 904,
  kStyle = 905,
  kSize = 906,
  kBlockSize = 907,
  kInlineSize = 908,
  kScrollState = 909,
  kInsetBlockStart = 910,
  kInsetBlockEnd = 911,
  kInsetInlineStart = 912,
  kInsetInlineEnd = 913,
  kAutoFill = 914,
  kAutoFit = 915,
  kVar = 916,
  kInternalVariableValue = 917,
  kEnv = 918,
  kArg = 919,
  kAvoidPage = 920,
  kPage = 921,
  kRecto = 922,
  kVerso = 923,
  kAvoidColumn = 924,
  kP3 = 925,
  kRec2020 = 926,
  kAdd = 927,
  kAutoAdd = 928,
  kTrue = 929,
  kFalse = 930,
  kNoPreference = 931,
  kDark = 932,
  kLight = 933,
  kOnly = 934,
  kReduce = 935,
  kActive = 936,
  kPreserveParentColor = 937,
  kBackButton = 938,
  kFabricated = 939,
  kSelector = 940,
  kContinuous = 941,
  kFolded = 942,
  kStable = 943,
  kBothEdges = 944,
  kMore = 945,
  kLess = 946,
  kCustom = 947,
  kCyclic = 948,
  kSymbolic = 949,
  kNumeric = 950,
  kAdditive = 951,
  kExtends = 952,
  kInternalSimpChineseInformal = 953,
  kInternalSimpChineseFormal = 954,
  kInternalTradChineseInformal = 955,
  kInternalTradChineseFormal = 956,
  kInternalKoreanHangulFormal = 957,
  kInternalKoreanHanjaInformal = 958,
  kInternalKoreanHanjaFormal = 959,
  kInternalHebrew = 960,
  kInternalLowerArmenian = 961,
  kInternalUpperArmenian = 962,
  kInternalEthiopicNumeric = 963,
  kBullets = 964,
  kNumbers = 965,
  kWords = 966,
  kStandard = 967,
  kHigh = 968,
  kConstrainedHigh = 969,
  kDynamicRangeLimitMix = 970,
  kLayer = 971,
  kSupports = 972,
  kColorContrast = 973,
  kVs = 974,
  kAA = 975,
  kAALarge = 976,
  kAAA = 977,
  kAAALarge = 978,
  kDrop = 979,
  kRaise = 980,
  kXywh = 981,
  kAnchor = 982,
  kAnchorSize = 983,
  kWidth = 984,
  kHeight = 985,
  kSelfBlock = 986,
  kSelfInline = 987,
  kImplicit = 988,
  kEntry = 989,
  kExit = 990,
  kEntryCrossing = 991,
  kExitCrossing = 992,
  kRoot = 993,
  kNearest = 994,
  kSelf = 995,
  kAllowDiscrete = 996,
  kInverted = 997,
  kEnabled = 998,
  kInitialOnly = 999,
  kXStart = 1000,
  kXEnd = 1001,
  kYStart = 1002,
  kYEnd = 1003,
  kXSelfStart = 1004,
  kXSelfEnd = 1005,
  kYSelfStart = 1006,
  kYSelfEnd = 1007,
  kInternalTextareaAuto = 1008,
  kMostWidth = 1009,
  kMostHeight = 1010,
  kMostBlockSize = 1011,
  kMostInlineSize = 1012,
  kFlipBlock = 1013,
  kFlipInline = 1014,
  kFlipStart = 1015,
  kFlexVisual = 1016,
  kFlexFlow = 1017,
  kGridRows = 1018,
  kGridColumns = 1019,
  kGridOrder = 1020,
  kContextFill = 1021,
  kContextStroke = 1022,
};

const int numCSSValueKeywords = 1023;
const size_t maxCSSValueKeywordLength = 42;

inline bool IsValidCSSValueID(CSSValueID id)
{
    return id != CSSValueID::kInvalid;
}

CORE_EXPORT const char* getValueName(CSSValueID);
bool isValueAllowedInMode(CSSValueID id, CSSParserMode mode);

}  // namespace blink

#endif  // THIRD_PARTY_BLINK_RENDERER_CORE_CSS_VALUE_KEYWORDS_H_
